@@ -1,7 +1,9 @@
 from base64 import b64encode, b64decode
 from datetime import datetime
+from hashlib import md5
 import json
 import logging
+from warnings import warn
 
 import django
 from django.core.exceptions import ImproperlyConfigured, MiddlewareNotUsed
@@ -25,8 +27,7 @@ class AgentMiddleware(object):
     """
     def __init__(self):
         if django.VERSION < (1, 4):
-            logger.error('django_agent_trust requires Django 1.4 or higher')
-
+            warn('django_agent_trust requires Django 1.4 or higher')
             raise MiddlewareNotUsed()
 
     def process_request(self, request):
@@ -116,7 +117,9 @@ class AgentMiddleware(object):
         return b64encode(json.dumps(agent.to_jsonable()))
 
     def _cookie_name(self, username):
-        return '{0}-{1}'.format(settings.AGENT_COOKIE_NAME, username)
+        suffix = md5(username.encode('utf-8')).hexdigest()[16:]
+
+        return '{0}-{1}'.format(settings.AGENT_COOKIE_NAME, suffix)
 
     def _max_cookie_age(self, agentsettings):
         """
